@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use base qw( Exporter );
 
-our $VERSION = '0.15_01';
+our $VERSION = '0.23_01';
 
 use AnyEvent::RipeRedis::Error;
 
@@ -506,6 +506,14 @@ sub _execute {
   my $self = shift;
   my $cmd  = shift;
 
+  if ( $self->{_multi_mode}
+    && ( exists $SUBUNSUB_CMDS{ $cmd->{name} }
+      || exists $NEED_POSTPROCESS{ $cmd->{name} } ) )
+  {
+    croak qq{Command "$cmd->{name}" not allowed after "multi" command.}
+        . ' First, the transaction must be finalized.';
+  }
+
   if ( exists $NEED_PREPROCESS{ $cmd->{name} } ) {
     if ( $cmd->{name} eq 'multi' ) {
       $self->{_multi_mode} = 1;
@@ -527,20 +535,7 @@ sub _execute {
       if ( exists $SUB_CMDS{ $cmd->{name} }
         && !defined $cmd->{on_message} )
       {
-        croak q{"on_message" callback must be specified};
-      }
-
-      if ( $self->{_multi_mode} ) {
-        AE::postpone {
-          my $err = _new_error(
-            qq{Command "$cmd->{name}" not allowed after "multi" command.}
-                . ' First, the transaction must be finalized.',
-            E_OPRN_ERROR
-          );
-          $cmd->{on_reply}->( undef, $err );
-        };
-
-        return;
+        croak '"on_message" callback must be specified';
       }
 
       if ( @{ $cmd->{args} } ) {
@@ -1215,10 +1210,11 @@ an error messages to C<STDERR>.
 
 =head2 <command>( [ @args ] [, $cb->( $reply, $err ) ] )
 
-To execute the command you must call specific method. The reply to the command
-is passed to the callback in first argument. If any error occurred during
-the command execution, the error object is passed to the callback in second
-argument. Error object is an instance of the class L<AnyEvent::RipeRedis::Error>.
+To execute the command you must call specific method with corresponding name.
+The reply to the command is passed to the callback in first argument. If any
+error occurred during the command execution, the error object is passed to the
+callback in second argument. Error object is an instance of the class
+L<AnyEvent::RipeRedis::Error>.
 
 The command callback is optional. If it is not specified and any error
 occurred, the C<on_error> callback of the client is called.
@@ -1814,7 +1810,8 @@ Get or set the C<on_error> callback.
 
 =head1 SEE ALSO
 
-L<AnyEvent>, L<Redis::hiredis>, L<Redis>, L<RedisDB>
+L<AnyEvent::RipeRedis::Cluster>, L<AnyEvent>, L<Redis::hiredis>, L<Redis>,
+L<RedisDB>
 
 =head1 AUTHOR
 
@@ -1846,8 +1843,7 @@ Ivan Kruglov
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2012-2016, Eugene Ponizovsky, E<lt>ponizovsky@gmail.comE<gt>,
-SMS Online, E<lt>dev.opensource@sms-online.comE<gt>. All rights reserved.
+Copyright (c) 2012-2016, Eugene Ponizovsky, SMS Online. All rights reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
